@@ -1,17 +1,19 @@
 import sys
+import subprocess
 
 from latestos.scraper.utils import get_os_scraper
 from latestos.files.json import update_json_release_file
 
+from latestos.vagrantup.check import VAGRANTUP_BOX_OS_LIST, vagrantup_check
+
 
 DEFAULT_JSON_FILENAME = "./template.json"
 
 
-def main():
+def main(os_name: str,
+         json_filename: str = DEFAULT_JSON_FILENAME,
+         bash_command: list = []):
     """ Entry point for the script """
-    # Get os_name, json_filename, bash_command from command line arguments
-    os_name, json_filename, bash_command = get_params()
-
     # Get the scraper depending on the OS name
     scraper = get_os_scraper(os_name)
 
@@ -20,9 +22,15 @@ def main():
 
     # Update the JSON file
     update_json_release_file(json_filename, iso_url, checksum_url, version)
-
     print(f"Updated {json_filename}")
 
+    # if OS is on vagrantup box os list, check if the version is up to date
+    if bash_command and os_name in VAGRANTUP_BOX_OS_LIST:
+        uptodate = vagrantup_check(os_name, version)
+
+        if not uptodate:
+            run_subprocess(bash_command)
+
 
 def get_params() -> tuple:
     """
@@ -41,9 +49,26 @@ def get_params() -> tuple:
     # Extract the necessary variables
     os_name = args[0]
     json_filename = args[1] if len(args) > 1 else DEFAULT_JSON_FILENAME
-    bash_command = args[2].split() if len(args) > 2 else []
+    bash_command = args[2:].split() if len(args) > 2 else []
 
     return os_name, json_filename, bash_command
 
+
+def run_subprocess(bash_command: list, verbose: bool = False):
+    """
+    Runs bash command.
+    """
+    # Open subprocess and run
+    process = subprocess.Popen(bash_command, stdout=subprocess.PIPE)
+    output, _ = process.communicate()
+
+    # Print the output if necessary
+    if verbose:
+        print(output)
+
+
 if __name__ == "__main__":
-    main()
+    # Get os_name, json_filename, bash_command from command line arguments
+    os_name, json_filename, bash_command = get_params()
+
+    main(os_name, json_filename, bash_command)
